function julia(re, im, resolution, escape, iter, dx, dy, zoom)
% JULIA(RE, IM, RESOLUTION, ESCAPE, ITER, DX, DY, ZOOM)
% draws the Julia set of the complex function h(z) = z^2 + c in
% nice colors. 
%    Parameters:
%      RE: Real part of c
%      IM: Imaginary part of c
%      RESOLUTION: Resolution of the image in pixels 
%      ESCAPE: Escape condition
%      ITER: Number of performed iterates
%      DX: x-position of the computation grid
%      DY: y-position of the computation grid
%      ZOOM: Scaling factor
%    Example:
%      julia(0.4,0.2,200,10,64,0,0,1)

% Author : Andreas Klimke, Stuttgart University
% Date   : Dec 10, 2002
% Version: 1.0
	
r = zeros(resolution, resolution);

if str2double(version('-release')) < 13
	% If the release is less than 13 (V6.5.x), perform vectorized
	% version of the algorithm

	c = re + i*im;
	x = 1 - linspace(2,0,resolution);
	[X,Y] = meshgrid(dx+x/zoom,dy+x/zoom);
	Z = X + i.*Y;
	r = zeros(resolution, resolution);

	for k = 1:iter
		disp(['Step #: ' num2str(k)]);
		% Set each element of z to z^2 + c if F == 0, otherwise do
		% nothing (set z = z);
		Z = Z.^2 + c;
		
		% Do the comparison for each z if break condition is reached, 
		% increase n by 1 if it is reached
		r = r + (abs(Z) <= escape);
	end
	disp('Done!');
else
	% Release number is 13 or more, i.e. a JIT compiler is
	% present. Perform the non-vectorized version of the algorithm
	% instead. 
	dy = dy - 1/zoom;
	dx = dx - 1/zoom;
	stepadd = 2/zoom/resolution;
	escape = escape ^2;
	zrn2 = 0;
	zi = dy;
	for m = 1:resolution
		zr = dx;
		for n = 1:resolution
			rmax = iter;
			zrn = zr;
			zin = zi;
			for k = 1:iter
				zrn2 = zrn * zrn - zin * zin + re;
				zin  = 2 * zin * zrn + im;
				zrn  = zrn2;
				if (zrn*zrn+zin*zin) > escape
					rmax = k;
					break
				end
			end
			r(m,n) = rmax;
			zr = zr + stepadd;
		end
		zi = zi + stepadd;
	end
end

imagesc(r);
axis equal; axis off;

